==> nextcloud-20.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dashboard/l10n/tr.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Pano",
    "Dashboard app" : "Pano uygulaması",
    "Show something" : "Bir şeyler görüntüle",
    "Customize" : "Özelleştir",
    "Edit widgets" : "Gereçleri düzenle",
    "Get more widgets from the app store" : "Uygulama mağazasından başka gereçler alın",
    "Change background image" : "Arka plan görselini değiştir",
    "Weather service" : "Hava durumu",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Kişisel gizliliğinizi korumak için Nextcloud sunucunuz hava durumu verilerini sizin adınıza ister. Böylece hava durumu hizmetine hiçbir kişisel bilgi aktarılmaz.",
    "Weather data from Met.no" : "Hava durumu verileri Met.no tarafından sağlanıyor",
    "geocoding with Nominatim" : "Nominatim ile coğrafi kodlama",
    "elevation data from OpenTopoData" : "yükseklik verileri OpenTopoData tarafından sağlanıyor",
    "Weather" : "Hava Durumu",
    "Status" : "Durum",
    "Good evening, {name}" : "İyi geceler, {name}",
    "Good evening" : "İyi geceler",
    "Good afternoon, {name}" : "Tünaydın, {name}",
    "Good afternoon" : "Tünaydın",
    "Good morning, {name}" : "Günaydın, {name}",
    "Good morning" : "Günaydın",
    "Good night, {name}" : "İyi geceler, {name}",
    "Good night" : "İyi geceler",
    "Pick from files" : "Dosyalardan seçin",
    "Default images" : "Varsayılan görseller",
    "Plain background" : "Düz arka plan",
    "Insert from {productName}" : "{productName} üzerinden ekle"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-20.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/dashboard/l10n/tr.js <==
OC.L10N.register(
    "dashboard",
    {
    "Dashboard" : "Pano",
    "Dashboard app" : "Pano uygulaması",
    "Show something" : "Bir şeyler görüntüle",
    "Customize" : "Özelleştir",
    "Edit widgets" : "Pano bileşenlerini düzenle",
    "Get more widgets from the app store" : "Uygulama mağazasından başka pano bileşenleri alın",
    "Change background image" : "Arka plan görselini değiştir",
    "Weather service" : "Hava durumu",
    "For your privacy, the weather data is requested by your Nextcloud server on your behalf so the weather service receives no personal information." : "Kişisel gizliliğinizi korumak için Nextcloud sunucunuz hava durumu verilerini sizin adınıza ister. Böylece hava durumu hizmetine hiçbir kişisel bilgi aktarılmaz.",
    "Weather data from Met.no" : "Hava durumu verileri Met.no tarafından sağlanıyor",
    "geocoding with Nominatim" : "Nominatim ile coğrafi kodlama",
    "elevation data from OpenTopoData" : "yükseklik verileri OpenTopoData tarafından sağlanıyor",
    "Weather" : "Hava Durumu",
    "Status" : "Durum",
    "Good evening, {name}" : "İyi geceler, {name}",
    "Good evening" : "İyi geceler",
    "Good afternoon, {name}" : "Tünaydın, {name}",
    "Good afternoon" : "Tünaydın",
    "Good morning, {name}" : "Günaydın, {name}",
    "Good morning" : "Günaydın",
    "Good night, {name}" : "İyi geceler, {name}",
    "Good night" : "İyi geceler",
    "Pick from files" : "Dosyalardan seçin",
    "Default images" : "Varsayılan görseller",
    "Plain background" : "Düz arka plan",
    "Insert from {productName}" : "{productName} üzerinden ekle"
},
"nplurals=2; plural=(n > 1);");
